@@ -16,7 +16,7 @@ try:
 except:
     openai.api_key = ""
 
-chat = on_command("/chat",  priority=5, block=False)
+chat = on_command(".chat",  priority=5, block=False)
 
 
 @chat.handle()
@@ -41,4 +41,4 @@ async def _(event: GroupMessageEvent, arg: Message = CommandArg()):
     response = openai.Completion.create(engine=data["model"], prompt=data["prompt"], max_tokens=data["max_tokens"], n=1, temperature=data["temperature"])
 
     # 打印返回的结果
-    print(response["choices"][0]["text"])
\ No newline at end of file
+    await chat.finish(response["choices"][0]["text"])
\ No newline at end of file
